@@ -95,6 +95,9 @@ FAILEDOPERATION_TATAGENTNOTSUPPORT = 'FailedOperation.TatAgentNotSupport'
 # 实例无法退还。
 FAILEDOPERATION_UNRETURNABLE = 'FailedOperation.Unreturnable'
 
+# 给定实例所在可用区不相同，请给定相同可用区的实例。
+FAILEDOPERATION_ZONEINCONSISTENT = 'FailedOperation.ZoneInconsistent'
+
 # 镜像配额超过了限制。
 IMAGEQUOTALIMITEXCEEDED = 'ImageQuotaLimitExceeded'
 
@@ -602,6 +605,9 @@ LIMITEXCEEDED_DISASTERRECOVERGROUP = 'LimitExceeded.DisasterRecoverGroup'
 # 特定实例包含的某个ENI的EIP数量已超过目标实例类型的EIP允许的最大值，请删除部分EIP后重试。
 LIMITEXCEEDED_EIPNUMLIMIT = 'LimitExceeded.EipNumLimit'
 
+# 网卡数量超过实例上限。
+LIMITEXCEEDED_ENILIMITINSTANCETYPE = 'LimitExceeded.EniLimitInstanceType'
+
 # 特定实例当前ENI数量已超过目标实例类型的ENI允许的最大值，需删除部分ENI后重试。
 LIMITEXCEEDED_ENINUMLIMIT = 'LimitExceeded.EniNumLimit'
 
@@ -701,6 +707,9 @@ RESOURCEINUSE_HPCCLUSTER = 'ResourceInUse.HpcCluster'
 # 该可用区已售罄
 RESOURCEINSUFFICIENT_AVAILABILITYZONESOLDOUT = 'ResourceInsufficient.AvailabilityZoneSoldOut'
 
+# 网段资源不足。
+RESOURCEINSUFFICIENT_CIDRBLOCK = 'ResourceInsufficient.CidrBlock'
+
 # 指定的云盘规格已售罄
 RESOURCEINSUFFICIENT_CLOUDDISKSOLDOUT = 'ResourceInsufficient.CloudDiskSoldOut'
 
