@@ -23,7 +23,7 @@ FAILEDOPERATION_CHECKDOMAINFAILED = 'FailedOperation.CheckDomainFailed'
 # 创建模板操作失败。
 FAILEDOPERATION_CREATETEMPLATEFAILED = 'FailedOperation.CreateTemplateFailed'
 
-# 删除模版操作失败，请稍后重试。
+# 删除模板操作失败，请稍后重试。
 FAILEDOPERATION_DELETETEMPLATEFAILED = 'FailedOperation.DeleteTemplateFailed'
 
 # 获取域名信息操作失败，请稍后重试。
@@ -35,15 +35,27 @@ FAILEDOPERATION_DESCRIBEDOMAINLISTFAILED = 'FailedOperation.DescribeDomainListFa
 # 查询模板操作失败。
 FAILEDOPERATION_DESCRIBETEMPLATEFAILED = 'FailedOperation.DescribeTemplateFailed'
 
+# 域名已过期，不允许操作。
+FAILEDOPERATION_DOMAINEXPIREDUNSUPPORTED = 'FailedOperation.DomainExpiredUnsupported'
+
 # 获取域名价格列表失败。
 FAILEDOPERATION_DOMAINPRICELISTFAILED = 'FailedOperation.DomainPriceListFailed'
 
 # 当前账号下已有相同的手机/邮箱，无需重复添加。
 FAILEDOPERATION_DUPLICATEPHONEEMAIL = 'FailedOperation.DuplicatePhoneEmail'
 
+# 获取域名价格失败。
+FAILEDOPERATION_GETDOMAINPRICEFAILED = 'FailedOperation.GetDomainPriceFailed'
+
 # 域名过户失败。
 FAILEDOPERATION_MODIFYDOMAINOWNERFAILED = 'FailedOperation.ModifyDomainOwnerFailed'
 
+# 权限不足。
+FAILEDOPERATION_PERMISSIONDENIED = 'FailedOperation.PermissionDenied'
+
+# 禁止的手机或邮箱。
+FAILEDOPERATION_PROHIBITPHONEEMAIL = 'FailedOperation.ProhibitPhoneEmail'
+
 # 域名注册操作失败，请稍后重试。
 FAILEDOPERATION_REGISTERDOMAIN = 'FailedOperation.RegisterDomain'
 
@@ -62,6 +74,9 @@ FAILEDOPERATION_SETDOMAINDNSFAILED = 'FailedOperation.SetDomainDnsFailed'
 # 信息模板超过可用数量上限，建议删除已有模板后重试。
 FAILEDOPERATION_TEMPLATEMAXNUMFAILED = 'FailedOperation.TemplateMaxNumFailed'
 
+# 域名提交转入失败，请稍后重试。
+FAILEDOPERATION_TRANSFERINDOMAINFAILED = 'FailedOperation.TransferInDomainFailed'
+
 # 上传图片操作失败。
 FAILEDOPERATION_UPLOADIMAGEFAILED = 'FailedOperation.UploadImageFailed'
 
@@ -86,12 +101,18 @@ INVALIDPARAMETER_CERTIFICATEIMAGEISINVALID = 'InvalidParameter.CertificateImageI
 # 类型只能为手机或者邮箱。
 INVALIDPARAMETER_CODETYPEISINVALID = 'InvalidParameter.CodeTypeIsInvalid'
 
+# 自定义 DNS Host 名称未找到。
+INVALIDPARAMETER_CUSTOMDNSNAMENOTFOUND = 'InvalidParameter.CustomDnsNameNotFound'
+
 # 无权限自定义DNS。
 INVALIDPARAMETER_CUSTOMDNSNOTALLOWED = 'InvalidParameter.CustomDnsNotAllowed'
 
 # 域名输入为空或者不正确。
 INVALIDPARAMETER_DOMAINNAMEISINVALID = 'InvalidParameter.DomainNameIsInvalid'
 
+# 自定义DNS Host 名称已经存在。
+INVALIDPARAMETER_DUPLICATECUSTOMDNSNAME = 'InvalidParameter.DuplicateCustomDnsName'
+
 # 存在重复域名，请检查后重新提交。
 INVALIDPARAMETER_DUPLICATEDOMAINEXISTS = 'InvalidParameter.DuplicateDomainExists'
 
@@ -158,6 +179,9 @@ INVALIDPARAMETER_VERIFYCODEISINVALID = 'InvalidParameter.VerifyCodeIsInvalid'
 # 邮编为空或者不合法。
 INVALIDPARAMETER_ZIPCODEISINVALID = 'InvalidParameter.ZipCodeIsInvalid'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 请求频率超过限制。
 LIMITEXCEEDED_REQUESTLIMIT = 'LimitExceeded.RequestLimit'
 
@@ -179,6 +203,9 @@ MISSINGPARAMETER_TEMPLATEIDISEXIST = 'MissingParameter.TemplateIdIsExist'
 # 请求的次数超过了频率限制。
 REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 
+# 资源被占用。
+RESOURCEINUSE = 'ResourceInUse'
+
 # 当前正在执行中的任务过多，请稍后再提交新的任务。
 RESOURCEINSUFFICIENT_OVERWORK = 'ResourceInsufficient.Overwork'
 
@@ -200,6 +227,9 @@ RESOURCEUNAVAILABLE_DOMAINISMODIFYINGDNS = 'ResourceUnavailable.DomainIsModifyin
 # 账户实名认证未通过。
 UNSUPPORTEDOPERATION_ACCOUNTREALNAME = 'UnsupportedOperation.AccountRealName'
 
+# 创建的自定义DNS Host数量已达到最大限制。
+UNSUPPORTEDOPERATION_CUSTOMHOSTOVERLIMIT = 'UnsupportedOperation.CustomHostOverLimit'
+
 # 当前域名未完成实名认证，无法完成该操作。
 UNSUPPORTEDOPERATION_DOMAINNOTVERIFIED = 'UnsupportedOperation.DomainNotVerified'
 
